############################################################################## 
#
#  File:    Content.py
#  Project: TClasses
#
#  (c) Lennart Regebro, 2000.
#
############################################################################## 
__doc__='''Content class, of CClasses product
Catalogaware DTML Method
'''
__version__='1.0'

from OFS.DTMLMethod import DTMLMethod
from Products.ZCatalog.CatalogAwareness import CatalogAware
from Globals import HTMLFile
import re

addContentForm = HTMLFile('addContentForm', globals()) 

def addContent(self, id, REQUEST=None):
    """Add a Content to a collection object."""
    self._setObject(id, Content(id))

    if REQUEST is not None:
        return self.manage_main(self, REQUEST, update_menu=1)

class Content( CatalogAware, DTMLMethod ): 
    """Content class, of CClasses product
    Content is a CatalogAware DTML Method. 
    """

    meta_type = 'Content'

    default_catalog = 'SearchCatalog'

    manage_editForm=HTMLFile('manageContentForm', globals())
    manage=manage_main=manage_editDocument=manage_editForm

    def manage_edit(self,data,SUBMIT='Change',dtpref_cols='50',
                    dtpref_rows='20',REQUEST=None):
      """Calls reindex_object"""
      DTMLMethod.manage_edit(self,data,'',SUBMIT,dtpref_cols,dtpref_rows,REQUEST)
      self.reindex_object()
      if REQUEST:
            message="Content changed."
            return self.manage_editForm(self,REQUEST,manage_tabs_message=message)

    def __init__(self, id):
        DTMLMethod.__init__(self, file='', __name__=id)

    def search_title(self):
        """returns the title of the parent"""
        t = 'No title'
        if hasattr(self, 'aq_parent'):
            parent=self.aq_parent
            if hasattr(parent, 'title'):
                t = parent.title
        return t

    def search_path(self):
        """returns the url of the parent"""
        t = ''
        if hasattr(self, 'aq_parent'):
            ob = self.aq_parent
            t = ob.absolute_url(relative=1) + '/' + t

        return t

    tagRegex = re.compile('<.*?>')
    
    def textToSearch(self):
        # returns the text to search for a ZCatalog
        t = self.tagRegex.sub('', self.raw)
        return t
 

    def summary(self):
        """Returns the 50 first characters or 'raw'"""
        t = self.textToSearch()
        return t[0:100]
