##############################################################################
#
#  File:    Navigator.py
#  Project: LUFClasses
#
#  (c) Lennart Regebro, 2000.
#
##############################################################################
__doc__='''Navigator class, of LUFClasses product
Navigator is used to do navigation.
'''
__version__='1.0'

from Products.ZCatalog.CatalogAwareness import CatalogAware
from Globals import HTMLFile
from Globals import Persistent
import OFS.SimpleItem
import Acquisition                # Various acquisition types.
import AccessControl.Role         # Zope Security management.

addNavigatorForm = HTMLFile('addNavigatorForm', globals())

def addNavigator(self, id, navigation_title='', REQUEST=None):
    """Add a Content to a collection object."""
    self._setObject(id, Navigator(id, navigation_title))
    if REQUEST is not None:
        return self.manage_main(self, REQUEST, update_menu=0)

class Navigator( CatalogAware, OFS.SimpleItem.Item, Persistent,
    Acquisition.Implicit, AccessControl.Role.RoleManager):
    """Navigator class, of LUFClasses product"""

    def __init__(self, id, navigation_title='', path='', navigation_order=0):
        self.id = id
        self.navigation_title = navigation_title
        self.navigation_order=navigation_order
        self.path = path
        self.default_catalog = 'NavigationCatalog'

    manage_options=(
        {'label':'Edit',     'action':'manage_main'},
        {'label':'Catalog',  'action':'manage_editCatalogerForm'},
        {'label':'Security', 'action':'manage_access'},
        {'label':'Undo',     'action':'manage_UndoForm'},
    )

    meta_type = 'Navigator'

    __ac_permissions__=(
        ('Edit Navigation',    ('manage', 'manage_main', 'manage_navigator',
                                'manage_navigatorForm', 'manage_editCatalogerForm') ),
 	('Change permissions', ('manage_access',) ),
	('View Borings',       ('',) ),
   )

    def manage_navigator(self,menu_path='',navigation_title='',navigation_order='',REQUEST=''):
        """Updates the navigator object"""
        self.navigation_title=navigation_title
        self.navigation_order=navigation_order
        self.menu_path=menu_path
        self.navigation_path = self.parent_path()
        self.reindex_object()
        if REQUEST:
            message="Content changed."
            return self.manage_navigatorForm(self,REQUEST,manage_tabs_message=message)

    manage = manage_main = manage_navigatorForm = HTMLFile('manageNavigatorForm', globals())

    def manage_afterAdd(self, item, container):
        """Sets default path"""
        try:
            direct_parent=self.aq_parent
            grand_parent=direct_parent.aq_parent
            self.menu_path=grand_parent.absolute_url(relative=1)
        except:
            self.menu_path=''

        self.navigation_path = self.parent_path()
        self.index_object()

    def title(self):
        """returns the title of the parent"""
        t = 'No title'
        if hasattr(self, 'aq_parent'):
            direct_parent=self.aq_parent
            if hasattr(direct_parent, 'title'):
                t = direct_parent.title
        return t

    def parent_path(self):
        """returns the path to the parent"""
        try:
            direct_parent=self.aq_parent
            t = direct_parent.absolute_url()
        except:
            t= '/'
        return t

#    def index_object(self):
#        """By some reason the self.url() does not seem to return exactly the same result
#           different times. Still don't know why. But since the unindex_method is based
#           on this deleting the same id as index_object indexed I save the self.url()
#           used when indexing in self.ZCID."""
#        self.ZCID = self.url()
#        if hasattr(self, self.default_catalog):
#            getattr(self, self.default_catalog).catalog_object(self, self.ZCID)
#
#    def unindex_object(self):
#        """And the I use self.ZCID when unindexing. Seems to work."""
#        if not hasattr(self, 'ZCID'):
#            self.ZCID = self.url()
#
#        if hasattr(self, self.default_catalog):
#            getattr(self, self.default_catalog).uncatalog_object(self.ZCID)

    def _postCopy(self, container, op=0):
        # Called after the copy is finished to accomodate special cases.
        self.navigation_path = self.parent_path()
        self.reindex_object()
